==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/DatePartDeltasDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DatePartDeltasDescription } from "./DatePartDeltasDescription";
/**
 * @hidden
 */
export let DatePartDeltasDescriptionMetadata = /*@__PURE__*/ (() => {
    class DatePartDeltasDescriptionMetadata extends Base {
        static b(a) {
            if (DatePartDeltasDescriptionMetadata.a == null) {
                DatePartDeltasDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DatePartDeltasDescriptionMetadata.c(DatePartDeltasDescriptionMetadata.a);
            }
            if (a.j(DatePartDeltasDescriptionMetadata.a)) {
                return;
            }
            a.y(DatePartDeltasDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Date", "Number:double");
            a.item("Month", "Number:double");
            a.item("Year", "Number:double");
            a.item("Hours", "Number:double");
            a.item("Minutes", "Number:double");
            a.item("Seconds", "Number:double");
        }
        static d(a) {
            DatePartDeltasDescriptionMetadata.b(a);
            a.aa("DatePartDeltas", () => new DatePartDeltasDescription());
            a.z("DatePartDeltas", DatePartDeltasDescriptionMetadata.a);
        }
    }
    DatePartDeltasDescriptionMetadata.$t = /*@__PURE__*/ markType(DatePartDeltasDescriptionMetadata, 'DatePartDeltasDescriptionMetadata');
    DatePartDeltasDescriptionMetadata.a = null;
    return DatePartDeltasDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DatePartDeltasDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DatePartDeltasDescription } from "./DatePartDeltasDescription";
/**
 * @hidden
 */
export let DatePartDeltasDescriptionMetadata = /*@__PURE__*/ (() => {
    class DatePartDeltasDescriptionMetadata extends Base {
        static b(a) {
            if (DatePartDeltasDescriptionMetadata.a == null) {
                DatePartDeltasDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DatePartDeltasDescriptionMetadata.c(DatePartDeltasDescriptionMetadata.a);
            }
            if (a.k(DatePartDeltasDescriptionMetadata.a)) {
                return;
            }
            a.aa(DatePartDeltasDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Date", "Number:double");
            a.item("Month", "Number:double");
            a.item("Year", "Number:double");
            a.item("Hours", "Number:double");
            a.item("Minutes", "Number:double");
            a.item("Seconds", "Number:double");
        }
        static d(a) {
            DatePartDeltasDescriptionMetadata.b(a);
            a.ac("DatePartDeltas", () => new DatePartDeltasDescription());
            a.ab("DatePartDeltas", DatePartDeltasDescriptionMetadata.a);
        }
    }
    DatePartDeltasDescriptionMetadata.$t = /*@__PURE__*/ markType(DatePartDeltasDescriptionMetadata, 'DatePartDeltasDescriptionMetadata');
    DatePartDeltasDescriptionMetadata.a = null;
    return DatePartDeltasDescriptionMetadata;
})();
